@@ -1,4 +1,4 @@
-# $Id: statemachine.py 10136 2025-05-20 15:48:27Z milde $
+# $Id: statemachine.py 10251 2025-09-22 21:00:13Z milde $
 # Author: David Goodger <goodger@python.org>
 # Copyright: This module has been placed in the public domain.
 
@@ -140,7 +140,6 @@ class StateMachine:
         - `initial_state`: a string, the class name of the initial state.
         - `debug`: a boolean; produce verbose output if true (nonzero).
         """
-
         self.input_lines = None
         """`StringList` of input lines (without newlines).
         Filled by `self.run()`."""
@@ -1406,7 +1405,7 @@ class StringList(ViewList):
             stripped = line.lstrip()
             if not stripped:            # blank line
                 if until_blank:
-                    blank_finish = 1
+                    blank_finish = True
                     break
             elif block_indent is None:
                 line_indent = len(line) - len(stripped)
@@ -1416,7 +1415,7 @@ class StringList(ViewList):
                     indent = min(indent, line_indent)
             end += 1
         else:
-            blank_finish = 1            # block ends at end of lines
+            blank_finish = True            # block ends at end of lines
         block = self[start:end]
         if first_indent is not None and block:
             block.data[0] = block.data[0][first_indent:]
@@ -1427,18 +1426,18 @@ class StringList(ViewList):
     def get_2D_block(self, top, left, bottom, right, strip_indent=True):
         block = self[top:bottom]
         indent = right
-        for i in range(len(block.data)):
-            # get slice from line, care for combining characters
-            ci = utils.column_indices(block.data[i])
+        for i, line in enumerate(block.data):
+            # trim line to block borders, allow for for combining characters
+            adjusted_indices = utils.column_indices(line)
             try:
-                left = ci[left]
+                left_i = adjusted_indices[left]
             except IndexError:
-                left += len(block.data[i]) - len(ci)
+                left_i = left
             try:
-                right = ci[right]
+                right_i = adjusted_indices[right]
             except IndexError:
-                right += len(block.data[i]) - len(ci)
-            block.data[i] = line = block.data[i][left:right].rstrip()
+                right_i = len(line)
+            block.data[i] = line = line[left_i:right_i].rstrip()
             if line:
                 indent = min(indent, len(line) - len(line.lstrip()))
         if strip_indent and 0 < indent < right:
